Each element is rendered in order. NULL elements render nothing (via the
plot.NULL() method) and nested gglist elements recurse, so a gglist that
contains other gglist objects (a list of lists of plots) renders every
leaf plot.
Each element is rendered in order. NULL elements render nothing (via the
plot.NULL() method) and nested gglist elements recurse, so a gglist that
contains other gglist objects (a list of lists of plots) renders every
leaf plot.